@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Prereqs::EnsurePP;
 
 our $DATE = '2015-05-15'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,8 +10,7 @@ use warnings;
 use Moose;
 with 'Dist::Zilla::Role::InstallTool';
 
-use IPC::System::Options qw(backtick);
-use JSON;
+use App::lcpan::Call qw(call_lcpan_script);
 use Module::Path::More qw(module_path);
 use Module::XSOrPP qw(is_pp);
 use namespace::autoclean;
@@ -23,12 +22,9 @@ sub setup_installer {
     my $rr_prereqs = $prereqs_hash->{runtime}{requires} // {};
 
     $self->log(["Listing prereqs ..."]);
-    my @cmd = ("lcpan", "deps", "-R", "--json",
-               grep {$_ ne 'perl'} keys %$rr_prereqs);
-    $self->log(["cmd: %s", \@cmd]);
-    my $res = backtick({die=>1}, @cmd);
-    $res = JSON->new->decode($res);
-    $self->log(["Prereqs: %s", $res]);
+    my $res = call_lcpan_script(argv=>[
+        "deps", "-R",
+        grep {$_ ne 'perl'} keys %$rr_prereqs]);
     my $has_err;
     for my $entry (@$res) {
         my $mod = $entry->{module};
@@ -63,7 +59,7 @@ Dist::Zilla::Plugin::Prereqs::EnsurePP - Make sure that prereqs (and their deps)
 
 =head1 VERSION
 
-This document describes version 0.05 of Dist::Zilla::Plugin::Prereqs::EnsurePP (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP), released on 2015-05-15.
+This document describes version 0.06 of Dist::Zilla::Plugin::Prereqs::EnsurePP (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP), released on 2015-05-15.
 
 =head1 SYNOPSIS
 
